import os

def generate_java_code(type_data_status_class):
    return f"""\
package esi.examwh.model.common.converter;

import esi.examwh.model.common.{type_data_status_class};
import jakarta.persistence.AttributeConverter;
import jakarta.persistence.Converter;

@Converter(autoApply = true)
public class {type_data_status_class}_CONVERTER implements AttributeConverter<{type_data_status_class}, Integer> {{
    @Override
    public Integer convertToDatabaseColumn({type_data_status_class} ae_type) {{
        if (ae_type == null) {{
            return null;
        }}
        return ae_type.getValue();
    }}

    @Override
    public {type_data_status_class} convertToEntityAttribute(Integer ai_value) {{
        if (ai_value == null) {{
            return null;
        }}
        return {type_data_status_class}.getEnum(ai_value);
    }}
}}
"""

def main():
    # Ensure the 'converter' directory exists
    if not os.path.exists('converter'):
        os.makedirs('converter')

    # List all .java files in the current directory
    java_files = [f for f in os.listdir('.') if f.endswith('.java') and not f.endswith('_CONVERTER.java')]

    # Extract class names from file names
    for file_name in java_files:
        class_name = os.path.splitext(file_name)[0]  # Remove the .java extension
        if class_name:
            java_code = generate_java_code(class_name)
            java_file_name = f"{class_name}_CONVERTER.java"
            file_path = os.path.join('converter', java_file_name)
            with open(file_path, "w") as file:
                file.write(java_code)
            
            print(f"Java file has been created: {file_path}")

if __name__ == "__main__":
    main()
